.. index:: examples_index

.. _examples_index:

Tutorials and example notebooks
===============================

Real use-cases
--------------

- `Harper et al, Research Data Accompanying "Computational Discovery of Novel Copper Phosphide Conversion Anode for Lithium-Ion Batteries" <https://github.com/harpaf13/data.copper-phosphides>`_.

Example Jupyter notebooks
-------------------------

.. toctree::

    notebooks/hull
    notebooks/matador_plot_styles
    notebooks/voltage_from_res_files
    notebooks/projected_spectral
    notebooks/phonon_results

Tutorials
---------

.. toctree::
    :maxdepth: 2

    tutorials/run3
    tutorials/mongo
